| get_ci_type.tabxplor_fmt | R Documentation |
Get confidence intervals type of fmt columns
## S3 method for class 'tabxplor_fmt'
get_ci_type(x, ...)
x |
The object to test, to get a field in, or to modify. |
... |
Used in methods to add arguments in the future. |
A single character with the ci_type attribute.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.