TRUE for a table built by tab, tab_reg or any of their
variants — i.e. for a tabxplor_tab (a tabxplor_grouped_tab with tab_vars).
tab_structure answers the fuller question: what structure is it, and what can be done
with it.
TRUE for a table built by tab, tab_reg or any of their
variants — i.e. for a tabxplor_tab (a tabxplor_grouped_tab with tab_vars).
tab_structure answers the fuller question: what structure is it, and what can be done
with it.