is_totcol.default: Test function for total columns

is_totcol.defaultR Documentation

Test function for total columns

Description

Test function for total columns

Usage

## Default S3 method:
is_totcol(x, ...)

Arguments

x

The object to test, to get a field in, or to modify.

...

Used in methods to add arguments in the future.

Value

A single logical vector with the totcol attribute


tabxplor documentation built on April 3, 2025, 8:56 p.m.